Struct ZwpPointerGesturesV1
pub struct ZwpPointerGesturesV1 { /* private fields */ }wayland and Linux only.Expand description
touchpad gestures
A global interface to provide semantic touchpad gestures for a given pointer.
Three gestures are currently supported: swipe, pinch, and hold. Pinch and swipe gestures follow a three-stage cycle: begin, update, end. Hold gestures follow a two-stage cycle: begin and end. All gestures are identified by a unique id.
Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.
See also the Request enum for this interface.